@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filtermboxtest.h"
-#include <MailImporter/FilterMBox>
 #include "filterimportertest.h"
+#include <MailImporter/FilterMBox>
 #include <QTest>
 
 FilterMBoxTest::FilterMBoxTest(QObject *parent)
@@ -26,7 +26,7 @@ void FilterMBoxTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterMBox filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QStringList());
@@ -38,7 +38,7 @@ void FilterMBoxTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterMBox filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QStringList() << QStringLiteral("/foo/kde/bla/toto/"));
