@@ -1,13 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filtersylpheedtest.h"
+#include "filterimportertest.h"
 #include "filterimportertestutil.h"
 #include <MailImporter/FilterSylpheed>
-#include "filterimportertest.h"
 #include <QTest>
 
 FilterSylpheedTest::FilterSylpheedTest(QObject *parent)
@@ -27,7 +27,7 @@ void FilterSylpheedTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterSylpheed filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QString());
@@ -39,7 +39,7 @@ void FilterSylpheedTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterSylpheed filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
@@ -51,7 +51,7 @@ void FilterSylpheedTest::canNotImportDataWhenHomeDirSelected()
 {
     MailImporter::FilterSylpheed filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QDir::homePath());
